==> kircd-1.1.0.tar.gz: kircd-1.1.0/src/httpd.h <==
/* $Id: httpd.h,v 1.4 2005/12/09 15:45:18 ichiro Exp $ */
/*
 * Copyright (c) 2004
 *	Ichiro FUKUHARA <ichiro@ichiro.org>.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by Ichiro FUKUHARA.
 * 4. The name of the company nor the name of the author may be used to
 *    endorse or promote products derived from this software without specific
 *    prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ICHIRO FUKUHARA ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ICHIRO FUKUHARA OR THE VOICES IN HIS HEAD BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

static char http_header0[] = {
	"HTTP/1.1 200 OK\r\n"
};

static char http_header1[] = {
	"Content-type: text/html\r\n"
	"\r\n"
};

static char http_header2[] = {
	"<html>\r\n<head>\r\n"
	"<META HTTP-EQUIV=\"Content-Type\" CONTENT=\"text/html;CHARSET=ISO2022-JP\">\r\n"
	"<title>kircd</title>\r\n</head>\r\n"
	"<body>\r\n"
};

static char ico_header10[] = {
	"Content-type: image/x-icon\r\n"
	"\r\n"
};

static char http_footer[] = {
	"\r\n</body></html>\r\n"
};

static char http_auth_401_header[] = {
	"HTTP/1.1 401 Access Denied\r\n"
	"WWW-Authenticate: Basic realm=\"KIRCD\"\r\n"
	"Content-type: text/html\r\n"
	"\r\n"
};

==> kircd-1.3.0.tar.gz: kircd-1.3.0/src/httpd.h <==
/* $Id: httpd.h,v 1.5 2005/12/16 17:55:25 ichiro Exp $ */
/*
 * Copyright (c) 2004
 *	Ichiro FUKUHARA <ichiro@ichiro.org>.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by Ichiro FUKUHARA.
 * 4. The name of the company nor the name of the author may be used to
 *    endorse or promote products derived from this software without specific
 *    prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ICHIRO FUKUHARA ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ICHIRO FUKUHARA OR THE VOICES IN HIS HEAD BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

static char http_header0[] = {
	"HTTP/1.1 200 OK\r\n"
};

static char http_contype[] = {
	"Content-Type: text/html; charset=ISO-2022-JP\r\n"
};

static char http_header1[] = {
	"<html>\r\n<head>\r\n"
	"<title>kircd</title>\r\n</head>\r\n"
	"<body>\r\n"
};

static char ico_header10[] = {
	"Content-type: image/x-icon\r\n"
	"\r\n"
};

static char http_footer[] = {
	"\r\n</body></html>\r\n"
};

static char http_auth_401_header[] = {
	"HTTP/1.1 401 Access Denied\r\n"
	"WWW-Authenticate: Basic realm=\"KIRCD\"\r\n"
	"Content-type: text/html\r\n"
};
